# Statbotics API

At Statbotics.io, our mission is to develop and distribute cutting-edge FRC data analysis. This PyPI package allows users to seamlessly query our API through Python, allowing for easier usage and integration with existing scouting and strategy systems.
